@@ -3,7 +3,7 @@
 #' List all possible chart settings for each chart type (0 = general, 1 = Landings, ...).
 #'
 #' @param SAGChartKey the type identifier of the SAG chart, e.g. 0, 1, 2, ...
-#' @param ... arguments passed to \code{\link{ices_get}}.
+#' @param ... arguments passed to \code{\link{sag_get}}.
 #'
 #' @return a data frame with SAG chart type IDs and settings IDs.
 #'
@@ -23,7 +23,7 @@ getSAGTypeGraphs <- function(...) {
   # call webservice
   old_value <- sag_use_token(TRUE)
   out <-
-    ices_get_cached(
+    sag_get_cached(
       sag_api("SAGTypeCharts"), ...
     )
 
@@ -36,7 +36,7 @@ getSAGTypeGraphs <- function(...) {
 getSAGTypeSettings <- function(SAGChartKey, ...) {
   # call webservice
   out <-
-    ices_get_cached(
+    sag_get_cached(
       sag_api("SettingsForChartType", SAGChartKey = SAGChartKey), ...
     )
 
